@@ -4,7 +4,7 @@ mod meta;
 mod ops;
 mod processor;
 
-pub use helpers::fix_orientation;
-pub use meta::{read_image_metadata, ImageMeta, ImageMetaResponse};
+pub use helpers::{fix_orientation, get_rotated_size};
+pub use meta::{ImageMeta, ImageMetaResponse, read_image_metadata};
 pub use ops::{ResizeInstructions, ResizeOperation};
 pub use processor::{EnqueueResponse, Processor, RESIZED_SUBDIR};
