@@ -1,14 +1,17 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
 use std::hash::BuildHasher;
+use std::sync::{Arc, Mutex};
 
 use config::Config;
-use libs::base64::engine::{general_purpose::STANDARD as standard_b64, Engine};
-use libs::tera::{
-    to_value, try_get_value, Error as TeraError, Filter as TeraFilter, Result as TeraResult, Tera,
-    Value,
+
+use base64::engine::{Engine, general_purpose::STANDARD as standard_b64};
+use markdown::{RenderContext, render_content};
+use regex::Regex;
+use tera::{
+    Error as TeraError, Filter as TeraFilter, Result as TeraResult, Tera, Value, to_value,
+    try_get_value,
 };
-use markdown::{render_content, RenderContext};
 
 #[derive(Debug)]
 pub struct MarkdownFilter {
@@ -78,6 +81,59 @@ pub fn base64_decode<S: BuildHasher>(
     Ok(to_value(as_str).unwrap())
 }
 
+#[derive(Debug)]
+pub struct RegexReplaceFilter {
+    re_cache: Arc<Mutex<HashMap<String, Regex>>>,
+}
+
+impl RegexReplaceFilter {
+    pub fn new() -> Self {
+        Self { re_cache: Arc::new(Mutex::new(HashMap::new())) }
+    }
+}
+
+impl Default for RegexReplaceFilter {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
+impl TeraFilter for RegexReplaceFilter {
+    fn filter(&self, value: &Value, args: &HashMap<String, Value>) -> TeraResult<Value> {
+        let text = try_get_value!("regex_replace", "value", String, value);
+        let pattern = match args.get("pattern") {
+            Some(val) => try_get_value!("regex_replace", "pattern", String, val),
+            None => {
+                return Err(TeraError::msg(
+                    "Filter `regex_replace` expected an arg called `pattern`",
+                ));
+            }
+        };
+        let rep = match args.get("rep") {
+            Some(val) => try_get_value!("regex_replace", "rep", String, val),
+            None => {
+                return Err(TeraError::msg("Filter `regex_replace` expected an arg called `rep`"));
+            }
+        };
+
+        let mut cache = self.re_cache.lock().expect("re_cache lock");
+        let replaced = {
+            match cache.get(&pattern) {
+                Some(pat) => pat.replace_all(&text, &rep),
+                None => {
+                    let pat = Regex::new(&pattern)
+                        .map_err(|e| format!("`regex_replace`: failed to compile regex: {}", e))?;
+                    let replaced = pat.replace_all(&text, &rep);
+                    cache.insert(pattern, pat);
+                    replaced
+                }
+            }
+        };
+
+        Ok(to_value(replaced).unwrap())
+    }
+}
+
 #[derive(Debug)]
 pub struct NumFormatFilter {
     default_language: String,
@@ -91,7 +147,7 @@ impl NumFormatFilter {
 
 impl TeraFilter for NumFormatFilter {
     fn filter(&self, value: &Value, args: &HashMap<String, Value>) -> TeraResult<Value> {
-        use libs::num_format::{Locale, ToFormattedString};
+        use num_format::{Locale, ToFormattedString};
 
         let num = try_get_value!("num_format", "value", i64, value);
         let locale = match args.get("locale") {
@@ -112,17 +168,25 @@ impl TeraFilter for NumFormatFilter {
 mod tests {
     use std::collections::HashMap;
 
-    use libs::tera::{to_value, Filter, Tera};
+    use tera::{Filter, Tera, to_value};
 
-    use super::{base64_decode, base64_encode, MarkdownFilter, NumFormatFilter};
-    use config::Config;
+    use super::{
+        MarkdownFilter, NumFormatFilter, RegexReplaceFilter, base64_decode, base64_encode,
+    };
+    use config::{Config, HighlightConfig, HighlightStyle, Highlighting, Registry};
+
+    fn get_test_registry() -> Registry {
+        let mut registry = Registry::builtin().unwrap();
+        registry.link_grammars();
+        registry
+    }
 
     #[test]
     fn markdown_filter() {
         let result = MarkdownFilter::new(Config::default(), HashMap::new(), Tera::default())
-            .filter(&to_value(&"# Hey").unwrap(), &HashMap::new());
+            .filter(&to_value("# Hey").unwrap(), &HashMap::new());
         assert!(result.is_ok());
-        assert_eq!(result.unwrap(), to_value(&"<h1 id=\"hey\">Hey</h1>\n").unwrap());
+        assert_eq!(result.unwrap(), to_value("<h1 id=\"hey\">Hey</h1>\n").unwrap());
     }
 
     #[test]
@@ -136,10 +200,10 @@ mod tests {
         let mut tera = Tera::default();
         tera.add_raw_template("shortcodes/explicitlang.html", "a{{ lang }}a").unwrap();
         let filter = MarkdownFilter { config, permalinks, tera };
-        let result = filter.filter(&to_value(&"{{ explicitlang(lang='jp') }}").unwrap(), &args);
+        let result = filter.filter(&to_value("{{ explicitlang(lang='jp') }}").unwrap(), &args);
         println!("{:?}", result);
         assert!(result.is_ok());
-        assert_eq!(result.unwrap(), to_value(&"ajpa").unwrap());
+        assert_eq!(result.unwrap(), to_value("ajpa").unwrap());
     }
 
     #[test]
@@ -148,11 +212,11 @@ mod tests {
         args.insert("inline".to_string(), to_value(true).unwrap());
         let result = MarkdownFilter::new(Config::default(), HashMap::new(), Tera::default())
             .filter(
-                &to_value(&"Using `map`, `filter`, and `fold` instead of `for`").unwrap(),
+                &to_value("Using `map`, `filter`, and `fold` instead of `for`").unwrap(),
                 &args,
             );
         assert!(result.is_ok());
-        assert_eq!(result.unwrap(), to_value(&"Using <code>map</code>, <code>filter</code>, and <code>fold</code> instead of <code>for</code>").unwrap());
+        assert_eq!(result.unwrap(), to_value("Using <code>map</code>, <code>filter</code>, and <code>fold</code> instead of <code>for</code>").unwrap());
     }
 
     // https://github.com/Keats/gutenberg/issues/417
@@ -163,7 +227,7 @@ mod tests {
         let result = MarkdownFilter::new(Config::default(), HashMap::new(), Tera::default())
             .filter(
                 &to_value(
-                    &r#"
+                    r#"
 |id|author_id|       timestamp_created|title                 |content           |
 |-:|--------:|-----------------------:|:---------------------|:-----------------|
 | 1|        1|2018-09-05 08:03:43.141Z|How to train your ORM |Badly written blog|
@@ -180,20 +244,27 @@ mod tests {
     #[test]
     fn markdown_filter_use_config_options() {
         let mut config = Config::default();
-        config.markdown.highlight_code = true;
+        config.markdown.highlighting = Some(Highlighting {
+            error_on_missing_language: false,
+            style: HighlightStyle::Inline,
+            theme: HighlightConfig::Single { theme: "github-dark".to_string() },
+            extra_grammars: vec![],
+            extra_themes: vec![],
+            registry: get_test_registry(),
+        });
         config.markdown.smart_punctuation = true;
         config.markdown.render_emoji = true;
         config.markdown.external_links_target_blank = true;
 
         let md = "Hello <https://google.com> :smile: ...";
         let result = MarkdownFilter::new(config.clone(), HashMap::new(), Tera::default())
-            .filter(&to_value(&md).unwrap(), &HashMap::new());
+            .filter(&to_value(md).unwrap(), &HashMap::new());
         assert!(result.is_ok());
-        assert_eq!(result.unwrap(), to_value(&"<p>Hello <a rel=\"noopener\" target=\"_blank\" href=\"https://google.com\">https://google.com</a> 😄 …</p>\n").unwrap());
+        assert_eq!(result.unwrap(), to_value("<p>Hello <a rel=\"noopener external\" target=\"_blank\" href=\"https://google.com\">https://google.com</a> 😄 …</p>\n").unwrap());
 
         let md = "```py\ni=0\n```";
         let result = MarkdownFilter::new(config, HashMap::new(), Tera::default())
-            .filter(&to_value(&md).unwrap(), &HashMap::new());
+            .filter(&to_value(md).unwrap(), &HashMap::new());
         assert!(result.is_ok());
         assert!(result.unwrap().as_str().unwrap().contains("style"));
     }
@@ -204,11 +275,11 @@ mod tests {
         permalinks.insert("blog/_index.md".to_string(), "/foo/blog".to_string());
         let md = "Hello. Check out [my blog](@/blog/_index.md)!";
         let result = MarkdownFilter::new(Config::default(), permalinks, Tera::default())
-            .filter(&to_value(&md).unwrap(), &HashMap::new());
+            .filter(&to_value(md).unwrap(), &HashMap::new());
         assert!(result.is_ok());
         assert_eq!(
             result.unwrap(),
-            to_value(&"<p>Hello. Check out <a href=\"/foo/blog\">my blog</a>!</p>\n").unwrap()
+            to_value("<p>Hello. Check out <a href=\"/foo/blog\">my blog</a>!</p>\n").unwrap()
         );
     }
 
@@ -251,6 +322,22 @@ mod tests {
         }
     }
 
+    #[test]
+    fn regex_replace_filter() {
+        let value = "Springsteen, Bruce";
+        let expected = "Bruce Springsteen";
+        let pattern = r"(?P<last>[^,\s]+),\s+(?P<first>\S+)";
+        let rep = "$first $last";
+        let mut args = HashMap::new();
+        args.insert("pattern".to_string(), to_value(pattern).unwrap());
+        args.insert("rep".to_string(), to_value(rep).unwrap());
+        let regex_replace = RegexReplaceFilter::new();
+        let result = regex_replace.filter(&to_value(value).unwrap(), &args);
+        assert!(result.is_ok());
+        assert_eq!(result.unwrap(), to_value(expected).unwrap());
+        assert!(regex_replace.re_cache.lock().unwrap().contains_key(pattern));
+    }
+
     #[test]
     fn num_format_filter() {
         let tests = vec![
