@@ -6,15 +6,16 @@ use std::path::PathBuf;
 use crate::global_fns::helpers::search_for_file;
 use config::Config;
 
-use libs::base64::engine::{general_purpose::STANDARD as standard_b64, Engine};
-use libs::sha2::{digest, Sha256, Sha384, Sha512};
-use libs::tera::{from_value, to_value, Function as TeraFn, Result, Value};
+use base64::engine::{Engine, general_purpose::STANDARD as standard_b64};
+use sha2::{Sha256, Sha384, Sha512, digest};
+use tera::{Function as TeraFn, Result, Value, from_value, to_value};
 use utils::site::resolve_internal_link;
 
-fn compute_hash<D: digest::Digest>(data: &[u8], as_base64: bool) -> String
+fn compute_hash<D>(data: &[u8], as_base64: bool) -> String
 where
-    digest::Output<D>: core::fmt::LowerHex,
     D: std::io::Write,
+    D: digest::Digest,
+    digest::Output<D>: core::fmt::LowerHex,
 {
     let mut hasher = D::new();
     hasher.update(data);
@@ -85,10 +86,7 @@ impl TeraFn for GetUrl {
 
         // if it starts with @/, resolve it as an internal link
         if path.starts_with("@/") {
-            let path_with_lang = match make_path_with_lang(path, &lang, &self.config) {
-                Ok(x) => x,
-                Err(e) => return Err(e),
-            };
+            let path_with_lang = make_path_with_lang(path, &lang, &self.config)?;
 
             match resolve_internal_link(&path_with_lang, &self.permalinks) {
                 Ok(resolved) => Ok(to_value(resolved.permalink).unwrap()),
@@ -140,7 +138,7 @@ impl TeraFn for GetUrl {
                             "`get_url`: Could not find or open file {}",
                             path_with_lang
                         )
-                        .into())
+                        .into());
                     }
                 };
             }
@@ -251,8 +249,8 @@ mod tests {
     use std::fs::{copy, create_dir};
     use std::path::PathBuf;
 
-    use libs::tera::{to_value, Function};
-    use tempfile::{tempdir, TempDir};
+    use tempfile::{TempDir, tempdir};
+    use tera::{Function, to_value};
 
     use config::Config;
     use utils::fs::create_file;
@@ -494,7 +492,7 @@ title = "A title"
     #[test]
     fn can_get_file_hash_sha256_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         args.insert("sha_type".to_string(), to_value(256).unwrap());
@@ -508,7 +506,7 @@ title = "A title"
     #[test]
     fn can_get_file_hash_sha256_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         args.insert("sha_type".to_string(), to_value(256).unwrap());
@@ -519,20 +517,20 @@ title = "A title"
     #[test]
     fn can_get_file_hash_sha384_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         args.insert("base64".to_string(), to_value(false).unwrap());
         assert_eq!(
             static_fn.call(&args).unwrap(),
             "141c09bd28899773b772bbe064d8b718fa1d6f2852b7eafd5ed6689d26b74883b79e2e814cd69d5b52ab476aa284c414"
-            );
+        );
     }
 
     #[test]
     fn can_get_file_hash_sha384() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         assert_eq!(
@@ -544,7 +542,7 @@ title = "A title"
     #[test]
     fn can_get_file_hash_sha512_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         args.insert("sha_type".to_string(), to_value(512).unwrap());
@@ -558,7 +556,7 @@ title = "A title"
     #[test]
     fn can_get_file_hash_sha512() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("app.css").unwrap());
         args.insert("sha_type".to_string(), to_value(512).unwrap());
@@ -571,7 +569,7 @@ title = "A title"
     #[test]
     fn can_get_hash_sha256_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         args.insert("sha_type".to_string(), to_value(256).unwrap());
@@ -585,7 +583,7 @@ title = "A title"
     #[test]
     fn can_get_hash_sha256_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         args.insert("sha_type".to_string(), to_value(256).unwrap());
@@ -596,20 +594,20 @@ title = "A title"
     #[test]
     fn can_get_hash_sha384_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         args.insert("base64".to_string(), to_value(false).unwrap());
         assert_eq!(
             static_fn.call(&args).unwrap(),
             "99514329186b2f6ae4a1329e7ee6c610a729636335174ac6b740f9028396fcc803d0e93863a7c3d90f86beee782f4f3f"
-            );
+        );
     }
 
     #[test]
     fn can_get_hash_sha384() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         assert_eq!(
@@ -621,7 +619,7 @@ title = "A title"
     #[test]
     fn can_get_hash_sha512_no_base64() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         args.insert("sha_type".to_string(), to_value(512).unwrap());
@@ -635,7 +633,7 @@ title = "A title"
     #[test]
     fn can_get_hash_sha512() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("literal".to_string(), to_value("Hello World").unwrap());
         args.insert("sha_type".to_string(), to_value(512).unwrap());
@@ -648,7 +646,7 @@ title = "A title"
     #[test]
     fn error_when_file_not_found_for_hash() {
         let dir = create_temp_dir();
-        let static_fn = GetHash::new(dir.into_path(), None, PathBuf::new());
+        let static_fn = GetHash::new(dir.keep(), None, PathBuf::new());
         let mut args = HashMap::new();
         args.insert("path".to_string(), to_value("doesnt-exist").unwrap());
         let err = format!("{}", static_fn.call(&args).unwrap_err());
