@@ -1,6 +1,7 @@
 #[macro_use]
 mod macros;
 
+mod build_info;
 mod content;
 mod files;
 mod helpers;
@@ -8,6 +9,7 @@ mod i18n;
 mod images;
 mod load_data;
 
+pub use self::build_info::Now;
 pub use self::content::{GetPage, GetSection, GetTaxonomy, GetTaxonomyTerm, GetTaxonomyUrl};
 pub use self::files::{GetHash, GetUrl};
 pub use self::i18n::Trans;
