@@ -1,13 +1,14 @@
+use std::net::IpAddr;
 use std::net::TcpListener;
 
-pub fn get_available_port(avoid: u16) -> Option<u16> {
+pub fn get_available_port(interface: IpAddr, avoid: u16) -> Option<u16> {
     // Start after "well-known" ports (0–1023) as they require superuser
     // privileges on UNIX-like operating systems.
-    (1024..9000).find(|port| *port != avoid && port_is_available(*port))
+    (1024..9000).find(|port| *port != avoid && port_is_available(interface, *port))
 }
 
-pub fn port_is_available(port: u16) -> bool {
-    TcpListener::bind(("127.0.0.1", port)).is_ok()
+pub fn port_is_available(interface: IpAddr, port: u16) -> bool {
+    TcpListener::bind((interface, port)).is_ok()
 }
 
 /// Returns whether a link starts with an HTTP(s) scheme.
