@@ -88,7 +88,7 @@ pub fn create_new_project(name: &str, force: bool) -> Result<()> {
 
     console::info("Welcome to Zola!");
     console::info("Please answer a few questions to get started quickly.");
-    console::info("Any choices made can be changed by modifying the `config.toml` file later.");
+    console::info("Any choices made can be changed by modifying the `zola.toml` file later.");
 
     let base_url = ask_url("> What is the URL of your site?", "https://example.com")?;
     let compile_sass = ask_bool("> Do you want to enable Sass compilation?", true)?;
@@ -119,7 +119,7 @@ fn populate(path: &Path, compile_sass: bool, config: &str) -> Result<()> {
     if !path.exists() {
         create_dir(path)?;
     }
-    create_file(&path.join("config.toml"), config)?;
+    create_file(&path.join("zola.toml"), config)?;
     create_dir(path.join("content"))?;
     create_dir(path.join("templates"))?;
     create_dir(path.join("static"))?;
@@ -198,7 +198,7 @@ mod tests {
         create_dir(&dir).expect("Could not create test directory");
         populate(&dir, true, "").expect("Could not populate zola directories");
 
-        assert!(dir.join("config.toml").exists());
+        assert!(dir.join("zola.toml").exists());
         assert!(dir.join("content").exists());
         assert!(dir.join("templates").exists());
         assert!(dir.join("static").exists());
@@ -218,7 +218,7 @@ mod tests {
         populate(&dir, true, "").expect("Could not populate zola directories");
 
         assert!(dir.exists());
-        assert!(dir.join("config.toml").exists());
+        assert!(dir.join("zola.toml").exists());
         assert!(dir.join("content").exists());
         assert!(dir.join("templates").exists());
         assert!(dir.join("static").exists());
