@@ -1,6 +1,7 @@
-use libs::time::Duration;
+use log;
 use std::convert::TryInto;
 use std::time::Instant;
+use time::Duration;
 
 use errors::Error;
 use site::Site;
@@ -8,7 +9,7 @@ use site::Site;
 /// Display in the console the number of pages/sections in the site
 pub fn notify_site_size(site: &Site) {
     let library = site.library.read().unwrap();
-    println!(
+    log::info!(
         "-> Creating {} pages ({} orphan) and {} sections",
         library.pages.len(),
         library.get_all_orphan_pages().len(),
@@ -20,7 +21,7 @@ pub fn notify_site_size(site: &Site) {
 pub fn check_site_summary(site: &Site) {
     let library = site.library.read().unwrap();
     let orphans = library.get_all_orphan_pages();
-    println!(
+    log::info!(
         "-> Site content: {} pages ({} orphan), {} sections",
         library.pages.len(),
         orphans.len(),
@@ -28,7 +29,7 @@ pub fn check_site_summary(site: &Site) {
     );
 
     for orphan in orphans {
-        console::warn(&format!("Orphan page found: {}", orphan.path));
+        log::warn!("Orphan page found: {}", orphan.path);
     }
 }
 
@@ -42,12 +43,12 @@ pub fn warn_about_ignored_pages(site: &Site) {
         .collect();
 
     if !ignored_pages.is_empty() {
-        console::warn(&format!(
+        log::warn!(
             "{} page(s) ignored (missing date or weight in a sorted section):",
             ignored_pages.len()
-        ));
+        );
         for path in ignored_pages {
-            console::warn(&format!("- {}", path.display()));
+            log::warn!("- {}", path.display());
         }
     }
 }
@@ -58,22 +59,22 @@ pub fn report_elapsed_time(instant: Instant) {
     let duration_ms = duration.whole_milliseconds() as f64;
 
     if duration_ms < 1000.0 {
-        console::success(&format!("Done in {duration_ms}ms.\n"));
+        log::info!("Done in {duration_ms}ms.\n");
     } else {
         let duration_sec = duration_ms / 1000.0;
-        console::success(&format!("Done in {:.1}s.\n", ((duration_sec * 10.0).round() / 10.0)));
+        log::info!("Done in {:.1}s.\n", ((duration_sec * 10.0).round() / 10.0));
     }
 }
 
 /// Display an error message and the actual error(s)
 pub fn unravel_errors(message: &str, error: &Error) {
     if !message.is_empty() {
-        console::error(message);
+        log::error!("{message}");
     }
-    console::error(&error.to_string());
+    log::error!("{error}");
     let mut cause = error.source();
     while let Some(e) = cause {
-        console::error(&format!("Reason: {e}"));
+        log::error!("Reason: {e}");
         cause = e.source();
     }
 }
